Trait frame_support::pallet_prelude::TypeInfo
pub trait TypeInfo {
type Identity: 'static + ?Sized;
// Required method
fn type_info() -> Type<MetaForm>;
}Expand description
Implementors return their meta type information.
Required Associated Types
type Identity: 'static + ?Sized
type Identity: 'static + ?Sized
The type identifying for which type info is provided.
Note
This is used to uniquely identify a type via core::any::TypeId::of. In most cases it
will just be Self, but can be used to unify different types which have the same encoded
representation e.g. reference types Box<T>, &T and &mut T.
Required Methods
fn type_info() -> Type<MetaForm>
fn type_info() -> Type<MetaForm>
Returns the static type identifier for Self.
Implementations on Foreign Types
impl<A, B, C, D, E, F, G, H, I, J> TypeInfo for (A, B, C, D, E, F, G, H, I, J)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
H: TypeInfo + 'static,
I: TypeInfo + 'static,
J: TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H, I, J> TypeInfo for (A, B, C, D, E, F, G, H, I, J)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G, H, I, J)
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
H: TypeInfo + 'static,
I: TypeInfo + 'static,
J: TypeInfo + 'static,
K: TypeInfo + 'static,
L: TypeInfo + 'static,
M: TypeInfo + 'static,
N: TypeInfo + 'static,
O: TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
H: TypeInfo + 'static,
I: TypeInfo + 'static,
J: TypeInfo + 'static,
K: TypeInfo + 'static,
L: TypeInfo + 'static,
M: TypeInfo + 'static,
N: TypeInfo + 'static,
O: TypeInfo + 'static,
P: TypeInfo + 'static,
Q: TypeInfo + 'static,
R: TypeInfo + 'static,
S: TypeInfo + 'static,
T: TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static, Q: TypeInfo + 'static, R: TypeInfo + 'static, S: TypeInfo + 'static, T: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T)
fn type_info() -> Type<MetaForm>
impl<Idx> TypeInfo for RangeInclusive<Idx>where
Idx: TypeInfo + 'static + PartialOrd<Idx> + Debug,
impl<Idx> TypeInfo for RangeInclusive<Idx>where Idx: TypeInfo + 'static + PartialOrd<Idx> + Debug,
type Identity = RangeInclusive<Idx>
fn type_info() -> Type<MetaForm>
impl TypeInfo for NonZeroI16
impl TypeInfo for NonZeroI16
type Identity = NonZeroI16
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
H: TypeInfo + 'static,
I: TypeInfo + 'static,
J: TypeInfo + 'static,
K: TypeInfo + 'static,
L: TypeInfo + 'static,
M: TypeInfo + 'static,
N: TypeInfo + 'static,
O: TypeInfo + 'static,
P: TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E, F, G, H, I> TypeInfo for (A, B, C, D, E, F, G, H, I)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
H: TypeInfo + 'static,
I: TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H, I> TypeInfo for (A, B, C, D, E, F, G, H, I)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G, H, I)
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E, F, G, H, I, J, K, L> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
H: TypeInfo + 'static,
I: TypeInfo + 'static,
J: TypeInfo + 'static,
K: TypeInfo + 'static,
L: TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H, I, J, K, L> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G, H, I, J, K, L)
fn type_info() -> Type<MetaForm>
impl<A, B, C, D> TypeInfo for (A, B, C, D)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
impl<A, B, C, D> TypeInfo for (A, B, C, D)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static,
type Identity = (A, B, C, D)
fn type_info() -> Type<MetaForm>
impl TypeInfo for NonZeroU128
impl TypeInfo for NonZeroU128
type Identity = NonZeroU128
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
H: TypeInfo + 'static,
I: TypeInfo + 'static,
J: TypeInfo + 'static,
K: TypeInfo + 'static,
L: TypeInfo + 'static,
M: TypeInfo + 'static,
N: TypeInfo + 'static,
O: TypeInfo + 'static,
P: TypeInfo + 'static,
Q: TypeInfo + 'static,
R: TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static, Q: TypeInfo + 'static, R: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R)
fn type_info() -> Type<MetaForm>
impl TypeInfo for NonZeroI128
impl TypeInfo for NonZeroI128
type Identity = NonZeroI128
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E> TypeInfo for (A, B, C, D, E)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
impl<A, B, C, D, E> TypeInfo for (A, B, C, D, E)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static,
type Identity = (A, B, C, D, E)
fn type_info() -> Type<MetaForm>
impl TypeInfo for NonZeroU32
impl TypeInfo for NonZeroU32
type Identity = NonZeroU32
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E, F, G> TypeInfo for (A, B, C, D, E, F, G)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
impl<A, B, C, D, E, F, G> TypeInfo for (A, B, C, D, E, F, G)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G)
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E, F, G, H> TypeInfo for (A, B, C, D, E, F, G, H)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
H: TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H> TypeInfo for (A, B, C, D, E, F, G, H)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G, H)
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
H: TypeInfo + 'static,
I: TypeInfo + 'static,
J: TypeInfo + 'static,
K: TypeInfo + 'static,
L: TypeInfo + 'static,
M: TypeInfo + 'static,
N: TypeInfo + 'static,
O: TypeInfo + 'static,
P: TypeInfo + 'static,
Q: TypeInfo + 'static,
R: TypeInfo + 'static,
S: TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static, Q: TypeInfo + 'static, R: TypeInfo + 'static, S: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S)
fn type_info() -> Type<MetaForm>
impl<T, O> TypeInfo for BitVec<T, O>where
T: BitStore + TypeInfo + 'static,
O: BitOrder + TypeInfo + 'static,
impl<T, O> TypeInfo for BitVec<T, O>where T: BitStore + TypeInfo + 'static, O: BitOrder + TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H, I, J, K> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
H: TypeInfo + 'static,
I: TypeInfo + 'static,
J: TypeInfo + 'static,
K: TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H, I, J, K> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G, H, I, J, K)
fn type_info() -> Type<MetaForm>
impl TypeInfo for NonZeroU16
impl TypeInfo for NonZeroU16
type Identity = NonZeroU16
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E, F> TypeInfo for (A, B, C, D, E, F)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
impl<A, B, C, D, E, F> TypeInfo for (A, B, C, D, E, F)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F)
fn type_info() -> Type<MetaForm>
impl TypeInfo for NonZeroI64
impl TypeInfo for NonZeroI64
type Identity = NonZeroI64
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
H: TypeInfo + 'static,
I: TypeInfo + 'static,
J: TypeInfo + 'static,
K: TypeInfo + 'static,
L: TypeInfo + 'static,
M: TypeInfo + 'static,
N: TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G, H, I, J, K, L, M, N)
fn type_info() -> Type<MetaForm>
impl TypeInfo for NonZeroI32
impl TypeInfo for NonZeroI32
type Identity = NonZeroI32
fn type_info() -> Type<MetaForm>
impl TypeInfo for NonZeroU64
impl TypeInfo for NonZeroU64
type Identity = NonZeroU64
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
H: TypeInfo + 'static,
I: TypeInfo + 'static,
J: TypeInfo + 'static,
K: TypeInfo + 'static,
L: TypeInfo + 'static,
M: TypeInfo + 'static,
N: TypeInfo + 'static,
O: TypeInfo + 'static,
P: TypeInfo + 'static,
Q: TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static, Q: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q)
fn type_info() -> Type<MetaForm>
impl<A, B, C, D, E, F, G, H, I, J, K, L, M> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
D: TypeInfo + 'static,
E: TypeInfo + 'static,
F: TypeInfo + 'static,
G: TypeInfo + 'static,
H: TypeInfo + 'static,
I: TypeInfo + 'static,
J: TypeInfo + 'static,
K: TypeInfo + 'static,
L: TypeInfo + 'static,
M: TypeInfo + 'static,
impl<A, B, C, D, E, F, G, H, I, J, K, L, M> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static,
type Identity = (A, B, C, D, E, F, G, H, I, J, K, L, M)
fn type_info() -> Type<MetaForm>
impl<A, B, C> TypeInfo for (A, B, C)where
A: TypeInfo + 'static,
B: TypeInfo + 'static,
C: TypeInfo + 'static,
impl<A, B, C> TypeInfo for (A, B, C)where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static,
sourceimpl TypeInfo for MultiSigner
impl TypeInfo for MultiSigner
sourceimpl TypeInfo for OpaqueExtrinsic
impl TypeInfo for OpaqueExtrinsic
sourceimpl TypeInfo for ModuleError
impl TypeInfo for ModuleError
sourceimpl<Header, Extrinsic> TypeInfo for Block<Header, Extrinsic>where
Header: TypeInfo + 'static,
Vec<Extrinsic, Global>: TypeInfo + 'static,
Extrinsic: TypeInfo + 'static,
impl<Header, Extrinsic> TypeInfo for Block<Header, Extrinsic>where Header: TypeInfo + 'static, Vec<Extrinsic, Global>: TypeInfo + 'static, Extrinsic: TypeInfo + 'static,
sourceimpl<AccountId, AccountIndex> TypeInfo for MultiAddress<AccountId, AccountIndex>where
AccountId: TypeInfo + 'static,
AccountIndex: HasCompact + TypeInfo + 'static,
impl<AccountId, AccountIndex> TypeInfo for MultiAddress<AccountId, AccountIndex>where AccountId: TypeInfo + 'static, AccountIndex: HasCompact + TypeInfo + 'static,
sourceimpl<'a> TypeInfo for PiecewiseLinear<'a>where
'a: 'static,
impl<'a> TypeInfo for PiecewiseLinear<'a>where 'a: 'static,
sourceimpl TypeInfo for ModuleError
impl TypeInfo for ModuleError
sourceimpl TypeInfo for MultiSignature
impl TypeInfo for MultiSignature
sourceimpl TypeInfo for BlakeTwo256
impl TypeInfo for BlakeTwo256
sourceimpl<Number, Hash> TypeInfo for Header<Number, Hash>where
Number: Copy + Into<U256> + TryFrom<U256> + HasCompact + TypeInfo + 'static,
Hash: Hash + 'static,
<Hash as Hash>::Output: TypeInfo + 'static,
impl<Number, Hash> TypeInfo for Header<Number, Hash>where Number: Copy + Into<U256> + TryFrom<U256> + HasCompact + TypeInfo + 'static, Hash: Hash + 'static, <Hash as Hash>::Output: TypeInfo + 'static,
sourceimpl<Xt> TypeInfo for Block<Xt>where
Vec<Xt, Global>: TypeInfo + 'static,
Xt: TypeInfo + 'static,
impl<Xt> TypeInfo for Block<Xt>where Vec<Xt, Global>: TypeInfo + 'static, Xt: TypeInfo + 'static,
sourceimpl TypeInfo for DispatchError
impl TypeInfo for DispatchError
sourceimpl TypeInfo for UintAuthorityId
impl TypeInfo for UintAuthorityId
sourceimpl<Info> TypeInfo for DispatchErrorWithPostInfo<Info>where
Info: Eq + PartialEq<Info> + Clone + Copy + Encode + Decode + Printable + TypeInfo + 'static,
impl<Info> TypeInfo for DispatchErrorWithPostInfo<Info>where Info: Eq + PartialEq<Info> + Clone + Copy + Encode + Decode + Printable + TypeInfo + 'static,
sourceimpl TypeInfo for TokenError
impl TypeInfo for TokenError
sourceimpl TypeInfo for TestSignature
impl TypeInfo for TestSignature
sourceimpl<Call, Extra> TypeInfo for TestXt<Call, Extra>where
Option<(u64, Extra)>: TypeInfo + 'static,
Call: TypeInfo + 'static,
Extra: TypeInfo + 'static,
impl<Call, Extra> TypeInfo for TestXt<Call, Extra>where Option<(u64, Extra)>: TypeInfo + 'static, Call: TypeInfo + 'static, Extra: TypeInfo + 'static,
sourceimpl TypeInfo for DigestItem
impl TypeInfo for DigestItem
sourceimpl TypeInfo for TransactionalError
impl TypeInfo for TransactionalError
sourceimpl TypeInfo for AnySignature
impl TypeInfo for AnySignature
sourceimpl<Address, Call, Signature, Extra> TypeInfo for UncheckedExtrinsic<Address, Call, Signature, Extra>where
Address: StaticTypeInfo,
Call: StaticTypeInfo,
Signature: StaticTypeInfo,
Extra: SignedExtension + StaticTypeInfo,
impl<Address, Call, Signature, Extra> TypeInfo for UncheckedExtrinsic<Address, Call, Signature, Extra>where Address: StaticTypeInfo, Call: StaticTypeInfo, Signature: StaticTypeInfo, Extra: SignedExtension + StaticTypeInfo,
Manual TypeInfo implementation because of custom encoding. The data is a valid encoded
Vec<u8>, but requires some logic to extract the signature and payload.
See UncheckedExtrinsic::encode and UncheckedExtrinsic::decode.